% 
% This file computes the two variables
% 
% -- 'priorxm' : Metric 3D coordinates of points on the grid. The unit is
%                1cm. 
% 
% -- 'priorxn' : Normalized  3D coordinates of points on the grid. The
%                center of mass of the points is [0;0;0], and the mean
%                squared coordinate be 1. 
% 
% 
% The 3D points in priorxm and priorxn are numbered in the same manner as in
% the file matches.m : 
% 
% Left half-grid first, left to right and bottom to top. 
% 
% Each half-grid (left and right) has 24 points, arranged in 4 rows of 6
% points each.
% 
% Approximate description of the grid : 
% 
% -- Each square is 5-by-5 cm.
% 
% -- The columns (resp. rows) formed by the points on one half-grid are
%    parallel to that on the other half-grid.
% 
% -- The closest point of one grid is at 0.5 cm from the plane containing the
%    other half-grid.
% 
% Author : Etienne Grossmann (IST)
% 

% 
% Metric prior coordinates of the calibration grid
% 

% First line of the y = 0 planes and x = zero planes.
% 6x(3+3)
priorxm = [ 0.5+5*(5:-1:0)' zeros(6,2) zeros(6,1)  0.5+5*(0:5)' zeros(6,1) ] ;
% Other lines
priorxm = kron(ones(4,1), priorxm) + kron(5*[0:3;0:3]',[zeros(6,2) ones(6,1)] ) ;
% Reshape
priorxm = [ priorxm(:,1:3) ; priorxm(:,4:6) ]' ;


% 
% Normalized coordinates, so that the center of mass of the points is
% [0;0;0], and the mean squared coordinate be 1.
% 
priorxn = priorxm - mean(priorxm')'*ones(1,Pall) ;
priorxn = priorxn./sqrt(mean(priorxn(:).^2)) ;
